0.0.9rc1.dev5
- Merge features

0.0.9rc1.dev4
- Fixed error reporting

0.0.9rc1.dev3
- Fixed formatting error

0.0.9rc1.dev2
- reworked REST API

0.0.9a3
- Minor fixes

0.0.9a1
- The first alpha version

0.0.1 Initial version
- Initial version